`instances` module
******************

Fabric tasks
------------

.. autofunction:: django_fabfile.instances.create_ami
.. autofunction:: django_fabfile.instances.create_encrypted_instance
.. autofunction:: django_fabfile.instances.create_instance
.. autofunction:: django_fabfile.instances.launch_instance_from_ami
.. autofunction:: django_fabfile.instances.modify_instance_termination
.. autofunction:: django_fabfile.instances.modify_kernel
.. autofunction:: django_fabfile.instances.mount_snapshot

Internals
---------

.. automodule:: django_fabfile.instances
   :members:
